import requests
import pygal
import json

from pygal.style import LightColorizedStyle as LCS, LightenStyle as LS

# 执行API调用并存储响应
url = 'https://api.github.com/search/repositories?q=language:python&sort=stars'
# 因为访问github api有访问次数限制，访问成功我生成一个 github_python_repositories.json 文件，如果达到限制次数，就读取本地的文件
filename = 'github_python_repositories.json'
try:
	r = requests.get(url)
	print("Status code: ", r.status_code)
	if r.status_code == 403:
		raise Exception('达到访问限制次数，一分钟后再试！')
	# 将API响应存储在一个变量中
	response_dict = r.json()
except Exception as err:
	print('访问github api 异常:', err)
	with open(filename) as f:
		response_dict = json.load(f)
else:
	# 将数据写入文件
	with open(filename, 'w') as f:
		f.write(r.text)

print("Total Repositories: ", response_dict['total_count'])

# 搜索有关仓库的信息
# repo_dicts 列表
repo_dicts = response_dict['items']
print("Repositories returned: ", len(repo_dicts))

names, plot_dicts = [], []
for repo_dict in repo_dicts:
	names.append(repo_dict['name'])

	# description 可能为空
	plot_dict = {
		'value': repo_dict['stargazers_count'],
		'label': str(repo_dict['description']),
		'xlink': repo_dict['html_url'],
	}
	plot_dicts.append(plot_dict)

# 可视化
# '#333366' 深蓝色
my_style = LS('#333366', base_style=LCS)

my_config = pygal.Config()
# x_label_rotation=45 让标签让x轴旋转45度
my_config.x_label_rotation = 45
# show_legend=False 隐藏图例
my_config.show_legend = False
# 将较长的项目名缩短为15个字符
my_config.truncate_label = 15
# 隐藏图表中的水平线
my_config.show_y_guides = False
# 设置宽度
my_config.width = 1000

chart = pygal.Bar(my_config, style=my_style)
chart.title = 'GitHub上更多的Star的python工程'
chart.x_labels = names

chart.add('', plot_dicts)
chart.render_to_file('python_repos.svg')
# 研究第一个仓库
# repo_dict = repo_dicts[0]
# print("\nkeys: ", len(repo_dict))
# for key in sorted(repo_dict.keys()):
# 	print(key)
# print("\n显示第一个仓库的信息：")
# print('Name:', repo_dict['name'])
# print('Owner:', repo_dict['owner']['login'])
# print('Star:', repo_dict['stargazers_count'])
# print('Repository:', repo_dict['html_url'])
# print('Created:', repo_dict['created_at'])
# print('Updated:', repo_dict['updated_at'])
# print('Description:', repo_dict['description'])
# 处理结果
# print(response_dict.keys())
